<?php

namespace App\Controller\OgBoot\OgLive;

use App\Controller\OgBoot\AbstractOgLiveController;
use App\Entity\OgLive;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\Attribute\AsController;
use Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

#[AsController]
class GetIsosAction extends AbstractOgLiveController
{
    /**
     * @throws TransportExceptionInterface
     * @throws ServerExceptionInterface
     * @throws RedirectionExceptionInterface
     * @throws ClientExceptionInterface
     */
    public function __invoke(HttpClientInterface $httpClient): JsonResponse
    {
        $ogLivesInserted = 0;

        try {
            $response = $httpClient->request('GET', $this->ogBootApiUrl.'/ogboot/v1/oglives/isos', [
                'headers' => [
                    'accept' => 'application/json',
                ],
            ]);
        } catch (TransportExceptionInterface $e) {
            return new JsonResponse( data: 'An error occurred', status: Response::HTTP_INTERNAL_SERVER_ERROR);
        }

        $data = json_decode($response->getContent(), true);

        if (!empty($data['downloads'])) {
            $ogLivesInserted = $this->insertOglives($data);
        }

        return new JsonResponse( data: [ 'data' => $data, 'ogLivesInserted' => $ogLivesInserted], status: Response::HTTP_OK);
    }

    public function insertOglives(array $data): int
    {
        $count = 0;

        foreach ($data['downloads'] as $ogLive ) {
            $ogLiveEntity = $this->entityManager->getRepository(OgLive::class)->findOneBy(['name' => $ogLive['filename']]);

            if ($ogLiveEntity) {
                continue;
            }

            $ogLiveEntity = new OgLive();
            $ogLiveEntity->setName($ogLive['filename']);
            $ogLiveEntity->setInstalled($ogLive['installed']);
            $ogLiveEntity->setFilename($ogLive['filename']);

            $this->entityManager->persist($ogLiveEntity);
            $count++;
        }

        $this->entityManager->flush();

        return $count;
    }
}