<?php

namespace App\Service\OgBoot\PxeBootFile;

use App\Entity\PxeBootFile;
use Symfony\Component\HttpClient\HttpClient;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Contracts\HttpClient\Exception\ClientExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\RedirectionExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

readonly class PostService
{
    public function __construct(
        private string              $ogBootApiUrl
    )
    {
    }

    /**
     * @throws TransportExceptionInterface
     * @throws ServerExceptionInterface
     * @throws RedirectionExceptionInterface
     * @throws ClientExceptionInterface
     */
    public function __invoke(PxeBootFile $bootFile)
    {
        $httpClient = HttpClient::create([
            'verify_peer' => false, // Ignorar la verificación del certificado SSL
            'verify_host' => false, // Ignorar la verificación del nombre del host
        ]);

        foreach ($bootFile->getClients() as $client) {
            $data = [
                'template_name' => $bootFile->getTemplate()->getName(),
                'mac' => $client->getMac(),
                'ip' => $client->getIp(),
                'server_ip' => '',
                'router' =>  $client->getOrganizationalUnit()->getNetworkSettings()->getRouter(),
                'netmask' => $client->getOrganizationalUnit()->getNetworkSettings()->getNetmask(),
                'computer_name' => $client->getName(),
                'netiface' => $client->getNetiface(),
                'group' => $client->getOrganizationalUnit()->getName(),
                'ogrepo' => $client->getRepository() ? $client->getRepository()->getIpAddress() : $client->getOrganizationalUnit()->getNetworkSettings()->getRepository()->getIpAddress(),
                'oglive' => '',
                'ogdns' => $client->getOrganizationalUnit()->getNetworkSettings()->getDns(),
                'ogProxy' => $client->getOrganizationalUnit()->getNetworkSettings()->getProxy(),
                'ogunit' => ''
            ];

            try {
                $response = $httpClient->request('POST', $this->ogBootApiUrl.'/ogboot/v1/pxes', [
                    'headers' => [
                        'accept' => 'application/json',
                    ],
                    'json' => $data
                ]);
            } catch (TransportExceptionInterface $e) {
                return new JsonResponse( data: 'An error occurred', status: Response::HTTP_INTERNAL_SERVER_ERROR);
            }

            return json_decode($response->getContent(), true);
        }

        return 1;
    }
}